//---------------------------------------------------------------------
//	lib_display.mq4
//---------------------------------------------------------------------
//	     .
//---------------------------------------------------------------------
//	  ,      :
//	- ;
//	- ;
//	-   ;
//---------------------------------------------------------------------

#property copyright "Copyright  2008, Dima S., ddd003@mail.ru"
#property link      "http://www.lapusja.ru"
//---------------------------------------------------------------------
#define LIB_DISPLAY_VERSION			"LIB_DISPLAY V1.00"
//---------------------------------------------------------------------

//=====================================================================
//	 :
//=====================================================================
#define ROWS				30												//     
#define COLUMNS			80												//     

//=====================================================================
//	 :
//=====================================================================
int			cell_x_position[ ROWS ][ COLUMNS ];		//  X   (   )
int			cell_y_position[ ROWS ][ COLUMNS ];		//  Y   (   )
//---------------------------------------------------------------------
color		cell_color[ ROWS ][ COLUMNS ];				//  
//---------------------------------------------------------------------
string	cell_font_name[ ROWS ][ COLUMNS ];		//   
int			cell_font_size[ ROWS ][ COLUMNS ];		//   
//---------------------------------------------------------------------
int			columns_number = COLUMNS;							//    
int			rows_number = ROWS;										//    
//---------------------------------------------------------------------
string	base_name = "";
//---------------------------------------------------------------------

//---------------------------------------------------------------------
//	  :
//---------------------------------------------------------------------
string
get_cell_name( int _cell_row, int _cell_column )
{
	string	cell_name = base_name + "_cell_" + DoubleToStr( _cell_row, 0 ) + "_" + DoubleToStr( _cell_column, 0 );
	return( cell_name );
}

//=====================================================================
//	    / :
//=====================================================================

//---------------------------------------------------------------------
//	    :
//---------------------------------------------------------------------
int
set_cell_attributes( int _cell_row, int _cell_column, int _cell_x_pos, int _cell_y_pos, color _cell_color = Silver, int _cell_font_size = 8, string	_cell_font_name = "Arial" )
{
	string	cell_name;

//	1.      ,    :
	if( _cell_row < 0 || _cell_row >= rows_number )
		return( -1 );

	if( _cell_column < 0 || _cell_column >= columns_number )
		return( -1 );

//	2.      :
	cell_color[ _cell_row ][ _cell_column ] = _cell_color;
	cell_font_size[ _cell_row ][ _cell_column ] = _cell_font_size;
	cell_font_name[ _cell_row ][ _cell_column ] = _cell_font_name;
	cell_x_position[ _cell_row ][ _cell_column ] = _cell_x_pos;
	cell_y_position[ _cell_row ][ _cell_column ] = _cell_y_pos;

//	3.   :
	cell_name = get_cell_name( _cell_row, _cell_column );
	ObjectSet( cell_name, OBJPROP_COLOR, _cell_color );
	ObjectSet( cell_name, OBJPROP_XDISTANCE, _cell_x_pos );
	ObjectSet( cell_name, OBJPROP_YDISTANCE, _cell_y_pos );

	return( 0 );
}

//---------------------------------------------------------------------
//	   :
//---------------------------------------------------------------------
void
set_cell_text( int _cell_row, int _cell_column, string _cell_text, color _cell_color = CLR_NONE, int _cell_font_size = 0, string	_cell_font_name = "" )
{
	string	cell_name;
	color 	c_color = _cell_color;
	int 		font_size = _cell_font_size;
	string	font_name = _cell_font_name;

	if( c_color == CLR_NONE )
		c_color = cell_color[ _cell_row ][ _cell_column ];

	if( font_size == 0 )
		font_size = cell_font_size[ _cell_row ][ _cell_column ];

	if( font_name == "" )
		font_name = cell_font_name[ _cell_row ][ _cell_column ];

	cell_name = get_cell_name( _cell_row, _cell_column );
	ObjectSetText( cell_name, _cell_text, font_size, font_name, c_color );
}

//---------------------------------------------------------------------
//	   :
//---------------------------------------------------------------------
void
clear_row( int _row, int _start_column = 0, int _end_column = COLUMNS )
{
	string	cell_name;
	int			end_column;

	if( _end_column == COLUMNS )
		end_column = columns_number;
	else
		end_column = _end_column;

	for( int column = _start_column; column < end_column; column++ )
	{
		cell_name = get_cell_name( _row, column );
		ObjectSetText( cell_name, "" );
	}
}

//---------------------------------------------------------------------
//	   :
//---------------------------------------------------------------------
void
clear_column( int _column, int _start_row = 0, int _end_row = ROWS )
{
	string	cell_name;
	int			end_row;

	if( _end_row == ROWS )
		end_row = rows_number;
	else
		end_row = _end_row;

	for( int row = _start_row; row < end_row; row++ )
	{
		cell_name = get_cell_name( row, _column );
		ObjectSetText( cell_name, "" );
	}
}


//=====================================================================
//	   :
//=====================================================================

//---------------------------------------------------------------------
//	 :
//---------------------------------------------------------------------
//	-    "_rows"   "_columns" ;
//	-      ( ,  );
//	- 
//---------------------------------------------------------------------
void
create_table( int _window_number, string _base_name, int _rows = ROWS, int _columns = COLUMNS )
{
	int			window_index;
	string	name;

	base_name = _base_name;

//	   :
	if( _columns <= 0 || _columns > COLUMNS )
		columns_number = COLUMNS;
	else
		columns_number = _columns;

//    :
	if( _rows <= 0 || _rows > ROWS )
		rows_number = ROWS;
	else
		rows_number = _rows;

//	    :
	for( int row = 0; row < rows_number; row++ )
	{
		for( int column = 0; column < columns_number; column++ )
		{
			name = get_cell_name( row, column );
			window_index = ObjectFind( name );

//	     ,   :
			if( window_index != _window_number )
			{
				ObjectCreate( name, OBJ_LABEL, _window_number, 0, 0 );
				ObjectSet( name, OBJPROP_CORNER, 0 );
			}
			else
			{
				ObjectSet( name, OBJPROP_CORNER, 0 );
			}
		}
	}	
}

//---------------------------------------------------------------------
//	 :
//---------------------------------------------------------------------
void
clear_table( int _start_row = 0, int _start_column = 0, int _end_row = ROWS, int _end_column = COLUMNS )
{
	int			window_index;
	int			end_row;
	int			end_column;
	string	name;

	if( _end_row == ROWS )
		end_row = rows_number;
	else
		end_row = _end_row;

	if( _end_column == COLUMNS )
		end_column = columns_number;
	else
		end_column = _end_column;

	for( int row = _start_row; row < end_row; row++ )
	{
		for( int column = _start_column; column < end_column; column++ )
		{
			name = get_cell_name( row, column );
			window_index = ObjectFind( name );
			if( window_index != -1 )
			{
				ObjectSetText( name, " " );
			}
		}
	}
}

//---------------------------------------------------------------------
//	    :
//---------------------------------------------------------------------
void
delete_table( )
{
	int			window_index;
	string	name;

	for( int row = 0; row < rows_number; row++ )
	{
		for( int column = 0; column < columns_number; column++ )
		{
			name = get_cell_name( row, column );
			window_index = ObjectFind( name );
			if( window_index != -1 )
			{
				ObjectDelete( name );
			}
		}
	}
}

